@@ -471,12 +471,13 @@ class Distribution(_Distribution):
         cls, patterns: list[str], enforce_match: bool = True
     ) -> Iterator[str]:
         """
-        >>> list(Distribution._expand_patterns(['LICENSE']))
-        ['LICENSE']
+        >>> getfixture('sample_project_cwd')
+        >>> list(Distribution._expand_patterns(['LICENSE.txt']))
+        ['LICENSE.txt']
         >>> list(Distribution._expand_patterns(['pyproject.toml', 'LIC*']))
-        ['pyproject.toml', 'LICENSE']
-        >>> list(Distribution._expand_patterns(['setuptools/**/pyprojecttoml.py']))
-        ['setuptools/config/pyprojecttoml.py']
+        ['pyproject.toml', 'LICENSE.txt']
+        >>> list(Distribution._expand_patterns(['src/**/*.dat']))
+        ['src/sample/package_data.dat']
         """
         return (
             path.replace(os.sep, "/")
@@ -488,8 +489,9 @@ class Distribution(_Distribution):
     @staticmethod
     def _find_pattern(pattern: str, enforce_match: bool = True) -> list[str]:
         r"""
-        >>> Distribution._find_pattern("LICENSE")
-        ['LICENSE']
+        >>> getfixture('sample_project_cwd')
+        >>> Distribution._find_pattern("LICENSE.txt")
+        ['LICENSE.txt']
         >>> Distribution._find_pattern("/LICENSE.MIT")
         Traceback (most recent call last):
         ...
@@ -626,21 +628,41 @@ class Distribution(_Distribution):
         if "-" not in opt or self._skip_setupcfg_normalization(section):
             return opt
 
-        raise InvalidConfigError(
+        underscore_opt = opt.replace('-', '_')
+        affected = f"(Affected: {self.metadata.name})." if self.metadata.name else ""
+        SetuptoolsDeprecationWarning.emit(
             f"Invalid dash-separated key {opt!r} in {section!r} (setup.cfg), "
-            f"please use the underscore name {opt.replace('-', '_')!r} instead."
+            f"please use the underscore name {underscore_opt!r} instead.",
+            f"""
+            Usage of dash-separated {opt!r} will not be supported in future
+            versions. Please use the underscore name {underscore_opt!r} instead.
+            {affected}
+            """,
+            see_docs="userguide/declarative_config.html",
+            due_date=(2026, 3, 3),
             # Warning initially introduced in 3 Mar 2021
         )
+        return underscore_opt
 
     def _enforce_option_lowercase(self, opt: str, section: str) -> str:
         if opt.islower() or self._skip_setupcfg_normalization(section):
             return opt
 
-        raise InvalidConfigError(
+        lowercase_opt = opt.lower()
+        affected = f"(Affected: {self.metadata.name})." if self.metadata.name else ""
+        SetuptoolsDeprecationWarning.emit(
             f"Invalid uppercase key {opt!r} in {section!r} (setup.cfg), "
-            f"please use lowercase {opt.lower()!r} instead."
+            f"please use lowercase {lowercase_opt!r} instead.",
+            f"""
+            Usage of uppercase key {opt!r} in {section!r} will not be supported in
+            future versions. Please use lowercase {lowercase_opt!r} instead.
+            {affected}
+            """,
+            see_docs="userguide/declarative_config.html",
+            due_date=(2026, 3, 3),
             # Warning initially introduced in 6 Mar 2021
         )
+        return lowercase_opt
 
     def _skip_setupcfg_normalization(self, section: str) -> bool:
         skip = (
